@@ -25,15 +25,11 @@ Serves to construct an association between a project + queue -> pool.
     }
 """
 
-from oslo_log import log as logging
-
 from zaqar.storage import base
 from zaqar.storage import errors
 from zaqar.storage.mongodb import utils
 
 
-LOG = logging.getLogger(__name__)
-
 PRIMARY_KEY = utils.PROJ_QUEUE_KEY
 
 CATALOGUE_INDEX = [
@@ -52,8 +48,8 @@ class CatalogueController(base.CatalogueBase):
     @utils.raises_conn_error
     def _insert(self, project, queue, pool, upsert):
         key = utils.scope_queue_name(queue, project)
-        return self._col.update({PRIMARY_KEY: key},
-                                {'$set': {'s': pool}}, upsert=upsert)
+        return self._col.update_one({PRIMARY_KEY: key},
+                                    {'$set': {'s': pool}}, upsert=upsert)
 
     @utils.raises_conn_error
     def list(self, project):
@@ -86,14 +82,14 @@ class CatalogueController(base.CatalogueBase):
 
     @utils.raises_conn_error
     def delete(self, project, queue):
-        self._col.remove({PRIMARY_KEY: utils.scope_queue_name(queue, project)},
-                         w=0)
+        self._col.delete_one({
+            PRIMARY_KEY: utils.scope_queue_name(queue, project)})
 
     def update(self, project, queue, pool=None):
         # NOTE(cpp-cabrera): _insert handles conn_error
         res = self._insert(project, queue, pool, upsert=False)
 
-        if not res['updatedExisting']:
+        if res.matched_count == 0:
             raise errors.QueueNotMapped(queue, project)
 
     @utils.raises_conn_error
