@@ -28,30 +28,17 @@ from zaqar.transport.wsgi import utils as wsgi_utils
 
 LOG = logging.getLogger(__name__)
 
+MESSAGE_POST_SPEC = (('ttl', int, None), ('body', '*', None))
+
 
 class CollectionResource(object):
 
-    __slots__ = (
-        '_message_controller',
-        '_queue_controller',
-        '_wsgi_conf',
-        '_validate',
-        '_message_post_spec',
-    )
-
-    def __init__(self, wsgi_conf, validate,
-                 message_controller, queue_controller,
-                 default_message_ttl):
+    __slots__ = ('_message_controller', '_wsgi_conf', '_validate')
 
+    def __init__(self, wsgi_conf, validate, message_controller):
         self._wsgi_conf = wsgi_conf
         self._validate = validate
         self._message_controller = message_controller
-        self._queue_controller = queue_controller
-
-        self._message_post_spec = (
-            ('ttl', int, default_message_ttl),
-            ('body', '*', None),
-        )
 
     # ----------------------------------------------------------------------
     # Helpers
@@ -80,10 +67,7 @@ class CollectionResource(object):
         if not messages:
             return None
 
-        messages = [wsgi_utils.format_message_v1_1(m, base_path, m['claim_id'])
-                    for m in messages]
-
-        return {'messages': messages}
+        return [wsgi_utils.format_message_v1(m, base_path) for m in messages]
 
     def _get(self, req, project_id, queue_name):
         client_uuid = wsgi_helpers.get_client_uuid(req)
@@ -112,9 +96,9 @@ class CollectionResource(object):
             LOG.debug(ex)
             raise wsgi_errors.HTTPBadRequestAPI(six.text_type(ex))
 
-        except storage_errors.QueueDoesNotExist as ex:
+        except storage_errors.DoesNotExist as ex:
             LOG.debug(ex)
-            messages = None
+            raise wsgi_errors.HTTPNotFound(six.text_type(ex))
 
         except Exception as ex:
             LOG.exception(ex)
@@ -122,28 +106,22 @@ class CollectionResource(object):
             raise wsgi_errors.HTTPServiceUnavailable(description)
 
         if not messages:
-            messages = []
+            return None
 
-        else:
-            # Found some messages, so prepare the response
-            kwargs['marker'] = next(results)
-            base_path = req.path.rsplit('/', 1)[0]
-            messages = [wsgi_utils.format_message_v1_1(m, base_path,
-                                                       m['claim_id'])
-                        for m in messages]
+        # Found some messages, so prepare the response
+        kwargs['marker'] = next(results)
+        base_path = req.path.rsplit('/', 1)[0]
+        messages = [wsgi_utils.format_message_v1(
+            m, base_path) for m in messages]
 
-        links = []
-        if messages:
-            links = [
+        return {
+            'messages': messages,
+            'links': [
                 {
                     'rel': 'next',
                     'href': req.path + falcon.to_query_str(kwargs)
                 }
             ]
-
-        return {
-            'messages': messages,
-            'links': links
         }
 
     # ----------------------------------------------------------------------
@@ -161,23 +139,14 @@ class CollectionResource(object):
             LOG.debug(ex)
             raise wsgi_errors.HTTPBadRequestAPI(six.text_type(ex))
 
-        # Deserialize and validate the incoming messages
+        # Deserialize and validate the request body
         document = wsgi_utils.deserialize(req.stream, req.content_length)
-
-        if 'messages' not in document:
-            description = _(u'No messages were found in the request body.')
-            raise wsgi_errors.HTTPBadRequestAPI(description)
-
-        messages = wsgi_utils.sanitize(document['messages'],
-                                       self._message_post_spec,
+        messages = wsgi_utils.sanitize(document, MESSAGE_POST_SPEC,
                                        doctype=wsgi_utils.JSONArray)
 
         try:
             self._validate.message_posting(messages)
 
-            if not self._queue_controller.exists(queue_name, project_id):
-                self._queue_controller.create(queue_name, project=project_id)
-
             message_ids = self._message_controller.post(
                 queue_name,
                 messages=messages,
@@ -207,92 +176,58 @@ class CollectionResource(object):
         resp.location = req.path + '?ids=' + ids_value
 
         hrefs = [req.path + '/' + id for id in message_ids]
-        body = {'resources': hrefs}
+
+        # NOTE(kgriffs): As of the Icehouse release, drivers are
+        # no longer allowed to enqueue a subset of the messages
+        # submitted by the client; it's all or nothing. Therefore,
+        # 'partial' is now always False in the v1.0 API, and the
+        # field has been removed in v1.1.
+        body = {'resources': hrefs, 'partial': False}
+
         resp.body = utils.to_json(body)
         resp.status = falcon.HTTP_201
 
     @decorators.TransportLog("Messages collection")
     def on_get(self, req, resp, project_id, queue_name):
-        ids = req.get_param_as_list('ids')
+        resp.content_location = req.relative_uri
 
+        ids = req.get_param_as_list('ids')
         if ids is None:
             response = self._get(req, project_id, queue_name)
-
         else:
             response = self._get_by_id(req.path.rsplit('/', 1)[0], project_id,
                                        queue_name, ids)
 
         if response is None:
-            # NOTE(TheSriram): Trying to get a message by id, should
-            # return the message if its present, otherwise a 404 since
-            # the message might have been deleted.
-            msg = _(u'No messages with IDs: {ids} found in the queue {queue} '
-                    u'for project {project}.')
-            description = msg.format(queue=queue_name, project=project_id,
-                                     ids=ids)
-            raise wsgi_errors.HTTPNotFound(description)
+            resp.status = falcon.HTTP_204
+            return
 
-        else:
-            resp.body = utils.to_json(response)
+        resp.body = utils.to_json(response)
         # status defaults to 200
 
     @decorators.TransportLog("Messages collection")
     def on_delete(self, req, resp, project_id, queue_name):
-        ids = req.get_param_as_list('ids')
-        pop_limit = req.get_param_as_int('pop')
-        try:
-            self._validate.message_deletion(ids, pop_limit)
+        # NOTE(zyuan): Attempt to delete the whole message collection
+        # (without an "ids" parameter) is not allowed
+        ids = req.get_param_as_list('ids', required=True)
 
-        except validation.ValidationFailed as ex:
-            LOG.debug(ex)
-            raise wsgi_errors.HTTPBadRequestAPI(six.text_type(ex))
-
-        if ids:
-            resp.status = self._delete_messages_by_id(queue_name, ids,
-                                                      project_id)
-
-        elif pop_limit:
-            resp.status, resp.body = self._pop_messages(queue_name,
-                                                        project_id,
-                                                        pop_limit)
-
-    def _delete_messages_by_id(self, queue_name, ids, project_id):
         try:
+            self._validate.message_listing(limit=len(ids))
             self._message_controller.bulk_delete(
                 queue_name,
                 message_ids=ids,
                 project=project_id)
 
+        except validation.ValidationFailed as ex:
+            LOG.debug(ex)
+            raise wsgi_errors.HTTPBadRequestAPI(six.text_type(ex))
+
         except Exception as ex:
             LOG.exception(ex)
             description = _(u'Messages could not be deleted.')
             raise wsgi_errors.HTTPServiceUnavailable(description)
 
-        return falcon.HTTP_204
-
-    def _pop_messages(self, queue_name, project_id, pop_limit):
-        try:
-            LOG.debug(u'POP messages - queue: %(queue)s, '
-                      u'project: %(project)s',
-                      {'queue': queue_name, 'project': project_id})
-
-            messages = self._message_controller.pop(
-                queue_name,
-                project=project_id,
-                limit=pop_limit)
-
-        except Exception as ex:
-            LOG.exception(ex)
-            description = _(u'Messages could not be popped.')
-            raise wsgi_errors.HTTPServiceUnavailable(description)
-
-        # Prepare response
-        if not messages:
-            messages = []
-        body = {'messages': messages}
-        body = utils.to_json(body)
-
-        return falcon.HTTP_200, body
+        resp.status = falcon.HTTP_204
 
 
 class ItemResource(object):
@@ -319,12 +254,9 @@ class ItemResource(object):
             description = _(u'Message could not be retrieved.')
             raise wsgi_errors.HTTPServiceUnavailable(description)
 
-        # Prepare response
-        message['href'] = req.path
-        message = wsgi_utils.format_message_v1_1(message,
-                                                 req.path.rsplit('/', 2)[0],
-                                                 message['claim_id'])
-
+        resp.content_location = req.relative_uri
+        message = wsgi_utils.format_message_v1(
+            message, req.path.rsplit('/', 2)[0])
         resp.body = utils.to_json(message)
         # status defaults to 200
 
