@@ -74,8 +74,6 @@ class Listing(object):
 
             for entry in flavors:
                 entry['href'] = request.path + '/' + entry['name']
-                # NOTE(wanghao): remove this in Newton.
-                entry['pool'] = entry['pool_group']
 
             results['links'] = [
                 {
@@ -101,9 +99,6 @@ class Resource(object):
         validator_type = jsonschema.Draft4Validator
         self._validators = {
             'create': validator_type(schema.create),
-            'pool_group': validator_type(schema.patch_pool_group),
-            # NOTE(wanghao): Remove this in Newton.
-            'pool': validator_type(schema.patch_pool),
             'capabilities': validator_type(schema.patch_capabilities),
         }
 
@@ -125,8 +120,6 @@ class Resource(object):
             data = self._ctrl.get(flavor,
                                   project=project_id,
                                   detailed=detailed)
-            # NOTE(wanghao): remove this in Newton.
-            data['pool'] = data['pool_group']
         except errors.FlavorDoesNotExist as ex:
             LOG.debug(ex)
             raise wsgi_errors.HTTPNotFound(six.text_type(ex))
@@ -140,7 +133,7 @@ class Resource(object):
 
         ::
 
-            {"pool_group": "my-pool-group", "capabilities": {}}
+            {"capabilities": {}}
 
         A capabilities object may also be provided.
 
@@ -151,19 +144,16 @@ class Resource(object):
 
         data = wsgi_utils.load(request)
         wsgi_utils.validate(self._validators['create'], data)
-        pool_group = data.get('pool_group') or data.get('pool')
         try:
             self._ctrl.create(flavor,
-                              pool_group=pool_group,
                               project=project_id,
                               capabilities=data['capabilities'])
             response.status = falcon.HTTP_201
             response.location = request.path
         except errors.PoolGroupDoesNotExist as ex:
             LOG.exception(ex)
-            description = (_(u'Flavor %(flavor)s could not be created. '
-                             u'Pool group %(pool_group)s does not exist') %
-                           dict(flavor=flavor, pool_group=pool_group))
+            description = (_(u'Flavor %(flavor)s could not be created. ') %
+                           dict(flavor=flavor))
             raise falcon.HTTPBadRequest(_('Unable to create'), description)
 
     def on_delete(self, request, response, project_id, flavor):
@@ -192,11 +182,11 @@ class Resource(object):
         LOG.debug(u'PATCH flavor - name: %s', flavor)
         data = wsgi_utils.load(request)
 
-        EXPECT = ('pool_group', 'capabilities', 'pool')
+        EXPECT = ('capabilities')
         if not any([(field in data) for field in EXPECT]):
             LOG.debug(u'PATCH flavor, bad params')
             raise wsgi_errors.HTTPBadRequestBody(
-                'One of `pool_group` or `capabilities`  or `pool` needs '
+                '`capabilities` needs '
                 'to be specified'
             )
 
@@ -205,10 +195,6 @@ class Resource(object):
 
         fields = common_utils.fields(data, EXPECT,
                                      pred=lambda v: v is not None)
-        # NOTE(wanghao): remove this in Newton.
-        if fields.get('pool') and fields.get('pool_group') is None:
-            fields['pool_group'] = fields.get('pool')
-            fields.pop('pool')
 
         try:
             self._ctrl.update(flavor, project=project_id, **fields)
