@@ -16,8 +16,10 @@
 from oslo_log import log as logging
 import six
 
+from zaqar.common import decorators
 from zaqar.i18n import _
 from zaqar.storage import errors as storage_errors
+from zaqar.transport import acl
 from zaqar.transport import utils
 from zaqar.transport.wsgi import errors as wsgi_errors
 
@@ -32,6 +34,8 @@ class Resource(object):
     def __init__(self, queue_controller):
         self._queue_ctrl = queue_controller
 
+    @decorators.TransportLog("Queues stats item")
+    @acl.enforce("queues:stats")
     def on_get(self, req, resp, project_id, queue_name):
         try:
             resp_dict = self._queue_ctrl.stats(queue_name,
@@ -50,11 +54,11 @@ class Resource(object):
                 oldest['href'] = base_path + oldest['id']
                 del oldest['id']
 
-            resp.content_location = req.path
             resp.body = utils.to_json(resp_dict)
             # status defaults to 200
 
-        except storage_errors.QueueIsEmpty as ex:
+        except (storage_errors.QueueDoesNotExist,
+                storage_errors.QueueIsEmpty) as ex:
             resp_dict = {
                 'messages': {
                     'claimed': 0,
@@ -63,6 +67,7 @@ class Resource(object):
                 }
             }
             resp.body = utils.to_json(resp_dict)
+
         except storage_errors.DoesNotExist as ex:
             LOG.debug(ex)
             raise wsgi_errors.HTTPNotFound(six.text_type(ex))
